%  Generating a stationary one-dimensional heat problem with inhomogeneous
%  Dirichlet problems.
%
%  Author: Martin Krosche
%          Institute of Scientific Computing
%          Technische Universitaet Braunschweig
%          Braunschweig, Germany
%
%  Copyright (c) 2009 Martin Krosche. All rights reserved. No warranty. No
%  liability.
%
%  [X, A, F] = HEAT_SYS( N ) returns nodes X (without Dirichlet nodes),
%  coefficient matrix A and RHS F from number N of inner discrete points
%  (without Dirichlet points) and in sparse data format.
function [x,A,f] = heat_sys( n );

  %  geometrical parameters.
  xmin   = 0;
  xmax   = 1;
  x      = linspace( xmin, xmax, n+2 );
  x      = x(2:end-1);
  delx   = (xmax-xmin)/(n+1);

  %  build coefficient matrix.
  w = -1.0/delx^2;
  A = build_coeff_matrix( n );
  A = w*A;

  %  build right-hand-side.
  f         = zeros( n, 1 );
  f( n, 1 ) = w;



%  A = BUILD_COEFF_MATRIX( N ) returns coefficient matrix from number N of inner
%  discrete points (without Dirichlet points) in sparse data format.
function A = build_coeff_matrix( n );

  d = ones( n, 1 );
  A = spdiags([-d 2*d -d], -1:1, n, n );
